Ext.define('AS.ARC.apps.vpnServer.log.log', {
	extend: 'AS.ARC.apps.vpnServer.page',
	pageTag: 'log',
	getPanel: function () {
		var page = this;

        var refreshBtn = Ext.create(Ext.button.Button, {
			text: _S('COMMON', 'REFRESH'),
			handler: function () {
				logGrid.store.load();
			}
		});

		var downloadBtn = Ext.create(Ext.button.Button, {
			text: _S('COMMON', 'DOWNLOAD'),
			disabled: true,
			handler: function () {
				//page.fn.app.maskWin(_S('COMMON', 'LOADING'));
				
				var download = Ext.create('Ext.form.FormPanel', {
					items: [{ xtype: 'filefield' }]
				}),
					uform = download.getForm();

				uform.submit({
					url: AS.ARC.util.getApiUrlWithSid(page.fn.apiUrl, {
						act: 'download',
						section: 'log'
					}),
					success: function (fp, o) {
						//page.fn.app.unmaskWin();
					},
					failure: function (form, action) {
						var json = Ext.decode(action.response.responseText);
						//page.fn.app.unmaskWin();
						AS.ARC.util.showMsgWindow({

						}, json, page.fn.win);

					}
				});
			}
		});

		var clearBtn = Ext.create(Ext.button.Button, {
			text: _S('COMMON', 'CLEAR'),
			handler: function () {
				page.fn.app.maskWin(_S('COMMON', 'LOADING'));
				var doClear = function (cb) {
					AS.ARC.ajax({
						url: AS.ARC.util.getApiUrlWithSid(page.fn.apiUrl, {
							act: 'clear',
							section: 'log'
						}),
						method: 'post',
						success: function (json, opts) {
							page.fn.app.unmaskWin();
							if (Ext.isFunction(cb)) cb();
						},
						failure: function (json, opts) {
							page.fn.app.unmaskWin();
							AS.ARC.util.showMsgWindow({

							}, json, page.fn.win);
						}
					});
				}
				var clearConfirm = Ext.create('AS.ARC.msgWindow', {
					title: _S('COMMON', 'CONFIRMATION'),
					parentWin: page.fn.win,
					// height: 160,
					iconType: 'question', // info, question, warning
					asItems: [{
						xtype: 'displayfield',
						value: _S('SYSTEMINFORMATION', 'NOTE_REMOVE_LOG')
					}],
					fbar: [{
						text: _S('COMMON', 'OK'),
						handler: function () {
							doClear(function () {
								logGrid.store.load();
								clearConfirm.close();
							});
						}
					},
					{
						text: _S('COMMON', 'CANCEL'),
						handler: function () {
							page.fn.app.unmaskWin();
							clearConfirm.close();
						},
						scope: this
					}]
				}).show();
			}
		});

        var topbar = Ext.create(AS.ARC.panelToolbarTop, {
			//cls: 'vpn-btn',
			//layout: 'hbox',
			items: [
				refreshBtn,
				downloadBtn,
				clearBtn,
				// {
				// 	xtype: 'tbfill'
				// },
				{
					xtype: 'asSearchField',
					itemId: 'search',
					listeners: {
						change: function (me, newValue) {
							logGrid.store.proxy.extraParams.keyword = newValue;
							logGrid.store.loadPage(1);
						}
					}
				}
			]
		});

        var filterInput = topbar.items.get('search');

		var logStore = Ext.create(Ext.data.Store, {
			pageSize: 25,
			autoLoad: false,			
			fields: ['time', 'user', 'protocol', 'event'],
			proxy: {
				type: 'ajax',
				url: AS.ARC.util.getApiUrlWithSid(page.fn.apiUrl, {
					act: 'get',
					section: 'log'
				}),
				extraParams: {
					keyword: filterInput.getValue()
				},
				actionMethods: {
					create: 'POST',
					read: 'POST',
					update: 'POST',
					destroy: 'POST'
				},
				reader: {
					type: 'json',
					root: 'log'
				}
			},
			listeners: {
				beforeload: function () {
					page.fn.app.maskWin(_S('COMMON', 'LOADING'));
				},
				load: function (me) {
					page.fn.app.unmaskWin();
					var json = me.proxy.reader.jsonData;
					if (json.log.length === 0) {
						downloadBtn.disable();
						clearBtn.disable();
					} else {
						downloadBtn.enable();
						clearBtn.enable();
					}
				},
				exception: function (proxy, response, operation, opts) {
					AS.ARC.util.showMsgWindow({
					}, Ext.JSON.decode(response.responseText), fn.win);
				}
			}
		});

        var logGrid = Ext.create(Ext.grid.Panel, {
			itemId: 'grid',
			height: 410,
			width: '100%',
			bodyStyle: 'border: none;',
			columns: [
				{
					dataIndex: 'time',
					flex: 1,
					align: 'center',
					header: _S('COMMON', 'TIME'),
					sortable: false,
					menuDisabled: true,
					renderer: function (value, metadata, record, rowIndex, colIndex, store) {
						var json = store.proxy.reader.jsonData,
							dateFormat = json.DateFormat,
							timeFormat = json.TimeFormat;
						
						value = AS.ARC.util.toSystemTime(dateFormat, timeFormat, value);
						metadata.tdAttr = 'data-qtip="' + value + '"';
						return value;
					}
				},
				{
					dataIndex: 'user',
					flex: 1,
					align: 'center',
					header: _S('COMMON', 'NAME'),
					sortable: false,
					menuDisabled: true,
					renderer: function (value, metadata) {
						metadata.tdAttr = 'data-qtip="' + value + '"';
						return value;
					}
				},
				{
					dataIndex: 'protocol',
					flex: 1,
					align: 'center',
					header: _S('VPN_SERVER', 'PROTOCOL'),
					sortable: false,
					menuDisabled: true,
					renderer: function (value, metadata) {
						metadata.tdAttr = 'data-qtip="' + value + '"';
						return value;
					}
				},
				{
					dataIndex: 'event',
					flex: 2,
					//align: 'center',
					header: _S('SYSTEMINFORMATION', 'EVENT'),
					sortable: false,
					menuDisabled: true,
					renderer: function (value, metadata) {
						metadata.tdAttr = 'data-qtip="' + value + '"';
						return value;
					}
				}
			],
			store: logStore,
			bbar: Ext.create('AS.ARC.pagingToolbar', {
				store: logStore
			})
		});
        
		return {
			xtype: 'asFnForm',
			page: page,
			itemId:  page.panelItemId,
			title: _S('SYSTEMINFORMATION', 'FN_LOG'),
			border: false,
			cls: 'as-page-panel',
			items: [
				topbar,
                logGrid
            ]
		};
	},

	loadData: function () {
		var page = this,
            topbar = page.panelItems.items[0],
            logGrid = page.panelItems.items[1]; 

        logGrid.store.load();
	}
});

/**
 * @class AS.ARC.apps.vpnServer.log.fn
 * @extends AS.ARC.apps.vpnServer.fn
 * <p></p>
 */
Ext.define('AS.ARC.apps.vpnServer.log.fn', {
	extend: 'AS.ARC.apps.vpnServer.fn',

	fnTag: 'log',
	
	init: function (config) {
		this.apiUrl = AS.ARC.util.getUserAppsPath() + 'vpn-server/vpnserver.cgi',
		this.imageUrl = AS.ARC.util.getUserAppsPath() + 'vpn-server/images/';
		
		this.createPanel();
		//this.loadData();
	},

	createPanel: function () {
		var fn = this;
		
		var pageLog = new AS.ARC.apps.vpnServer.log.log({fn: this});
			
		this.tabPanel = Ext.create('AS.ARC.fnTabPanel', {
			items: [
				pageLog.getPanel()
			],
			listeners: {
				tabchange: function(tabpanel) {
					var activeIndex = tabpanel.items.indexOf(tabpanel.getLayout().activeItem);
				},
				resize: function( main, adjWidth, adjHeight, eOpts ) {
					var reHeight = main.getHeight();
					main.down('#grid').setHeight(reHeight - 150);
					Ps.update(this.el.dom.querySelector('.x-panel-body'));
				}
			}
		});

		//fn.tabPanel.enableDataConfirm();
		fn.initMainPanel();
	},
	
	loadData: function () {
		this.tabPanel.activeTab.page.loadData(true);
	}
});